BaseExecutor

Struct BaseExecutor 

pub struct BaseExecutor<'a> { /* private fields */ }
An executor builds the S3 request.

use hyper::Method;
use bytes::Bytes;
use reqwest::Response;
use minio_rsc::Minio;
use minio_rsc::error::Result;

async fn get_object(minio:Minio)-> Result<Response> {
    let executor = minio.executor(Method::GET);
    let res: Response = executor
        .bucket_name("bucket")
        .object_name("test.txt")
        .query("versionId", "cdabf31a-9752-4265-b137-6b3961fbaf9b")
        .send_ok()
        .await?;
    Ok(res)
}

async fn put_object(minio:Minio, data:Bytes)-> Result<()> {
    let executor = minio.executor(Method::PUT);
    let res: Response = executor
        .bucket_name("bucket")
        .object_name("test.txt")
        .body(data)
        .send_ok()
        .await?;
    Ok(())
}

Implementations

Source

impl<'a> BaseExecutor<'a>

pub fn new(method: Method, client: &'a Minio) -> Self

pub fn method(self, method: Method) -> Self

Set the request method.

pub fn bucket_name<T: Into<String>>(self, name: T) -> Self

Set the bucket name.

pub fn object_name<T: Into<String>>(self, name: T) -> Self

Set the object name.

pub fn region<T: Into<String>>(self, region: T) -> Self

Set the region.

pub fn body<B: Into<Data<Error>>>(self, body: B) -> Self

Set the request body.

pub fn headers(self, header: HeaderMap) -> Self

Set the new request header.

pub fn header<K, V>(self, key: K, value: V) -> Self

Inserts a key-value pair into the request header.

pub fn headers_merge(self, header: HeaderMap) -> Self

Merge header into request header.

pub fn headers_merge2(self, header: Option<HeaderMap>) -> Self

Merge header into request header.

pub fn querys(self, querys: QueryMap) -> Self

Set up a new request query.

pub fn querys_merge(self, querys: QueryMap) -> Self

Merge querys into request query.

pub fn query<K: Into<String>, V: Into<String>>(self, key: K, value: V) -> Self

Inserts a key-value pair into the query map.

pub fn query_string(self, query_str: &str) -> Self

Inserts query_string into the query map.

pub fn apply<F>(self, apply: F) -> Self
where F: FnOnce(Self) -> Self,

pub async fn send(self) -> Result<Response>

Send an HTTP request to S3 and return a Result<Response>.

note: this is just a response from the s3 service, probably a wrong response.

pub async fn send_ok(self) -> Result<Response>

Send an HTTP request to S3 and return a Result<Response>.

This checks if the request is a legitimate S3 response.

pub async fn send_text_ok(self) -> Result<String>

Send an HTTP request to S3 and return a Result<String>.

This checks if the request is a legitimate S3 response.