pub struct ListObjectVersionsArgs {
pub delimiter: Option<String>,
pub encoding_type: Option<String>,
pub extra_headers: Option<HeaderMap>,
pub key_marker: Option<String>,
pub prefix: Option<String>,
pub max_keys: usize,
pub version_id_marker: Option<String>,
}Fields
delimiter: Option<String>encoding_type: Option<String>extra_headers: Option<HeaderMap>key_marker: Option<String>Specifies the key to start with when listing objects in a bucket.
prefix: Option<String>max_keys: usizeSets the maximum number of keys returned in the response. Default 1,000
version_id_marker: Option<String>Specifies the object version you want to start listing from.