pub struct ListObjectsArgs { /* private fields */ }Expand description
Custom list_objects request parameters
parmas
- prefix: Limits the response to keys that begin with the specified prefix.
- delimiter: A delimiter is a character you use to group keys.
- continuation_token: ContinuationToken indicates Amazon S3 that the list is being continued on this bucket with a token.
- max_keys: Sets the maximum number of keys returned in the response. Default 1000
- encoding_type:Encoding type used by Amazon S3 to encode object keys in the response.Valid Values:
url
Implementations
Sourceimpl ListObjectsArgs
impl ListObjectsArgs
pub fn continuation_token<T: Into<String>>(self, token: T) -> Self
pub fn delimiter<T: Into<String>>(self, delimiter: T) -> Self
pub fn use_encoding_type(self, use_encoding_type: bool) -> Self
pub fn fetch_owner(self, fetch_owner: bool) -> Self
pub fn start_after<T: Into<String>>(self, start_after: T) -> Self
pub fn max_keys(self, max_keys: usize) -> Self
pub fn prefix<T: Into<String>>(self, prefix: T) -> Self
Sourcepub fn extra_headers(self, extra_headers: Option<HeaderMap>) -> Self
pub fn extra_headers(self, extra_headers: Option<HeaderMap>) -> Self
Set extra headers for advanced usage.