ObjectLockConfig

Struct ObjectLockConfig 

pub struct ObjectLockConfig { /* private fields */ }
The container element for Object Lock configuration parameters.
see put_object_lock_configuration and get_object_lock_configuration API.

Note: both mode and duration settings will be effective.

Implementations

Source

impl ObjectLockConfig

pub fn new(duration: usize, is_day: bool, is_governance: bool) -> Self

pub fn config(&mut self, duration: usize, is_day: bool, is_governance: bool)

  • is_day: set period Days if true, otherwise set mode Years
  • is_governance: set mode GOVERNANCE if true, otherwise set mode COMPLIANCE.
pub fn duration(&self) -> usize

The date on which this Object Lock Retention will expire.

pub fn mode(&self) -> &str

Valid Values: GOVERNANCE | COMPLIANCE

pub fn period(&self) -> &str

period, Valid Values: Days | Years | Empty String