pub struct DefaultRetention {
pub days: Option<usize>,
pub mode: RetentionMode,
pub years: Option<usize>,
}Expand description
The container element for specifying the default Object Lock retention settings for new objects placed in the specified bucket.
Note
- The DefaultRetention settings require both a
modeand aperiod. - The DefaultRetention period can be either Days or Years but you must select one. You cannot specify Days and Years at the same time.
Fields
days: Option<usize>mode: RetentionModeyears: Option<usize>Trait Implementations
Sourceimpl Clone for DefaultRetention
impl Clone for DefaultRetention
Sourcefn clone(&self) -> DefaultRetention
fn clone(&self) -> DefaultRetention
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultRetention
impl Debug for DefaultRetention
Sourceimpl Default for DefaultRetention
impl Default for DefaultRetention
Sourcefn default() -> DefaultRetention
fn default() -> DefaultRetention
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DefaultRetention
impl<'de> Deserialize<'de> for DefaultRetention
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more