pub struct SelectRequest { /* private fields */ }Expand description
select_object_content method parameters.
Implementations
Sourceimpl SelectRequest
impl SelectRequest
Sourcepub fn new(
expression: String,
input_serialization: InputSerialization,
output_serialization: OutputSerialization,
request_progress: bool,
scan_start_range: Option<usize>,
scan_end_range: Option<usize>,
) -> Self
pub fn new( expression: String, input_serialization: InputSerialization, output_serialization: OutputSerialization, request_progress: bool, scan_start_range: Option<usize>, scan_end_range: Option<usize>, ) -> Self
Params:
- expression: The expression that is used to query the object.\
- input_serialization: InputSerialization Describes the format of the data in the object that is being queried.
- output_serialization: OutputSerialization Describes the format of the data that you want Amazon S3 to return in response.
- request_progress: Specifies if periodic request progress information should be enabled.
- scan_start_range: Optional, Specifies the start of the byte range.
- scan_end_range: Optional, Specifies the end of the byte range.