pub struct VersioningConfiguration {
pub mfa_delete: Option<MFADelete>,
pub status: Option<VersioningStatus>,
}Expand description
Describes the versioning state of an Amazon S3 bucket.
Fields
mfa_delete: Option<MFADelete>Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is only returned if the bucket has been configured with MFA delete. If the bucket has never been so configured, this element is not returned.
Valid Values: Enabled | Disabled
status: Option<VersioningStatus>The versioning state of the bucket.
Valid Values: Enabled | Suspended